Module: Google::Cloud::ApigeeRegistry
- Defined in:
- lib/google/cloud/apigee_registry.rb,
lib/google/cloud/apigee_registry/version.rb
Constant Summary collapse
- VERSION =
"1.5.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.apigee_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-apigee_registry library.
-
.provisioning(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Provisioning.
-
.provisioning_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Provisioning service is supported by the current client.
-
.registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Registry.
-
.registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Registry service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.apigee_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-apigee_registry library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
218 219 220 221 222 |
# File 'lib/google/cloud/apigee_registry.rb', line 218 def self.configure yield ::Google::Cloud.configure.apigee_registry if block_given? ::Google::Cloud.configure.apigee_registry end |
.provisioning(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Provisioning.
By default, this returns an instance of
Google::Cloud::ApigeeRegistry::V1::Provisioning::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Provisioning service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Provisioning service. You can determine whether the method will succeed by calling provisioning_available?.
About Provisioning
The service that is used for managing the data plane provisioning of the Registry.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/cloud/apigee_registry.rb', line 76 def self.provisioning version: :v1, transport: :grpc, &block require "google/cloud/apigee_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ApigeeRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::ApigeeRegistry.const_get(package_name).const_get(:Provisioning) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.provisioning_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Provisioning service is supported by the current client. If true, you can retrieve a client object by calling provisioning. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Provisioning service, or if the versioned client gem needs an update to support the Provisioning service.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/google/cloud/apigee_registry.rb', line 100 def self.provisioning_available? version: :v1, transport: :grpc require "google/cloud/apigee_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ApigeeRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::ApigeeRegistry.const_get package_name return false unless service_module.const_defined? :Provisioning service_module = service_module.const_get :Provisioning if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Registry.
By default, this returns an instance of
Google::Cloud::ApigeeRegistry::V1::Registry::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Registry service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Registry service. You can determine whether the method will succeed by calling registry_available?.
About Registry
The Registry service allows teams to manage descriptions of APIs.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/google/cloud/apigee_registry.rb', line 146 def self.registry version: :v1, transport: :grpc, &block require "google/cloud/apigee_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ApigeeRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::ApigeeRegistry.const_get(package_name).const_get(:Registry) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Registry service is supported by the current client. If true, you can retrieve a client object by calling registry. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Registry service, or if the versioned client gem needs an update to support the Registry service.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/cloud/apigee_registry.rb', line 170 def self.registry_available? version: :v1, transport: :grpc require "google/cloud/apigee_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ApigeeRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::ApigeeRegistry.const_get package_name return false unless service_module.const_defined? :Registry service_module = service_module.const_get :Registry if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |